@@ -2,12 +2,11 @@ package PerlIO::locale;
 
 use 5.008;
 use strict;
-use DynaLoader;
+use XSLoader;
 use PerlIO::encoding;
-our @ISA = qw(DynaLoader);
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
-bootstrap PerlIO::locale;
+XSLoader::load('PerlIO::locale', $VERSION);
 
 1;
 
@@ -17,6 +16,10 @@ __END__
 
 PerlIO::locale - PerlIO layer to use the encoding of the current locale
 
+=head1 VERSION
+
+0.07
+
 =head1 SYNOPSIS
 
     use PerlIO::locale;
@@ -34,15 +37,26 @@ to the locale currently in effect, if perl can guess it.
 
 =head1 AUTHOR
 
-Copyright (c) 2004, 2005, 2007, 2008 Rafael Garcia-Suarez <rgarciasuarez@gmail.com>.
+Copyright (c) 2004, 2005, 2007, 2008, 2011 Rafael Garcia-Suarez <rgs@consttype.org>,
+rewritten by Leon Timmermans <leont@cpan.org>
 
 =head1 LICENSE
 
 This program is free software; you may redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 SOURCE
+
+A git repository for the sources is at L<https://github.com/rgs/PerlIO-locale>.
+
 =head1 SEE ALSO
 
-L<open>.
+=over 4
+
+=item * L<open>.
+
+=item * L<PerlIO::encoding>
+
+=back
 
 =cut
